@@ -18,6 +18,15 @@ class Seq(func):
     def __getattr__(self, *args, **kwargs):
         return self._l.__getattribute__(*args, **kwargs)
 
+    def __getitem__(self, *args, **kwargs):
+        return self._l.__getitem__(*args, **kwargs)
+
+    def __str__(self):
+        return f"#Seq{str(self._l)}"
+
+    def __repr__(self):
+        return f"#Seq{repr(self._l)}"
+
     def split(self, pred):
         a = []
         b = []
@@ -26,7 +35,7 @@ class Seq(func):
                 a.append(v)
             else:
                 b.append(v)
-        return Seq(a), Seq(b)
+        return a, b
 
     def filter(self, pred):
         return get0(self.split(pred))
@@ -41,6 +50,15 @@ class Map(func):
     def __getattr__(self, *args, **kwargs):
         return self._m.__getattribute__(*args, **kwargs)
 
+    def __getitem__(self, *args, **kwargs):
+        return self._m.__getitem__(*args, **kwargs)
+
+    def __str__(self):
+        return f"#Map{str(self._m)}"
+
+    def __repr__(self):
+        return f"#Map{repr(self._m)}"
+
     def split(self, pred):
         a = {}
         b = {}
@@ -49,7 +67,7 @@ class Map(func):
                 a[k] = v
             else:
                 b[k] = v
-        return Map(a), Map(b)
+        return a, b
 
     def filter(self, pred):
         return get0(self.split(pred))
